;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'vhdl-print '("vhdl-mode"))
(custom-add-loads 'vhdl-sequential-process '("vhdl-mode"))
(custom-add-loads 'vhdl-port '("vhdl-mode"))
(custom-add-loads 'vhdl-header '("vhdl-mode"))
(custom-add-loads 'vhdl-speedbar '("vhdl-mode"))
(custom-add-loads 'vhdl-style '("vhdl-mode"))
(custom-add-loads 'vhdl-template '("vhdl-mode"))
(custom-add-loads 'vhdl-highlight '("vhdl-mode"))
(custom-add-loads 'vhdl-project '("vhdl-mode"))
(custom-add-loads 'vhdl-comment '("vhdl-mode"))
(custom-add-loads 'vhdl-testbench '("vhdl-mode"))
(custom-add-loads 'vhdl-highlight-faces '("vhdl-mode"))
(custom-add-loads 'vhdl-menu '("vhdl-mode"))
(custom-add-loads 'vhdl-align '("vhdl-mode"))
(custom-add-loads 'vhdl-compile '("vhdl-mode"))
(custom-add-loads 'font-lock-highlighting-faces '("vhdl-mode"))
(custom-add-loads 'languages '("vhdl-mode"))
(custom-add-loads 'vhdl-model '("vhdl-mode"))
(custom-add-loads 'vhdl-misc '("vhdl-mode"))
(custom-add-loads 'vhdl '("vhdl-mode"))
(custom-add-loads 'vhdl-mode '("vhdl-mode"))
(custom-add-loads 'speedbar-faces '("vhdl-mode"))

;;; custom-load.el ends here
